@@ -6,7 +6,7 @@
 # change 'tests => 1' to 'tests => last_test_to_print';
 
 use Test;
-BEGIN { plan tests => 4 };
+BEGIN { plan tests => 5 };
 use Chess::PGN::EPD;
 ok(1); # If we made it this far, we're ok.
 
@@ -28,6 +28,7 @@ while (<DATA>) {
 ok(ECO(\@epd),'C00');
 ok(NIC(\@epd),'FR 1');
 ok(Opening(\@epd),'French: Labourdonnais variation');
+ok(Knight());
 
 sub ECO {
     my $movesref = shift;
@@ -47,6 +48,12 @@ sub Opening {
     return epdcode('Opening',$movesref);
 }
 
+sub Knight {
+    my @epd = epdlist(qw(e4 c5 f4 Nf6 Nc3 d5 e5 d4 exf6 dxc3 fxg7 cxd2));
+
+    return 1;
+}
+
 __DATA__
 e4 e6 f4 d5 e5 c5 Nf3 Nc6 d3 Be7 Be2 Nh6 c3 O-O O-O f6
 exf6 Bxf6 d4 cxd4 cxd4 Qb6 Nc3 Bxd4+ Kh1 Bxc3 bxc3 Ng4
